Struct conch_runtime::env::atomic::ArgsEnv[][src]

pub struct ArgsEnv<T> { /* fields omitted */ }

An environment module for setting and getting shell and function arguments.

Uses Arc internally. If Send and Sync is not required of the implementation, see env::ArgsEnv as a cheaper alternative.

Methods

impl<T> AtomicArgsEnv<T>
[src]

Constructs a new environment and initializes it with the name of the current process as the shell name, and no arguments.

Constructs a new environment and initializes it with the provided name and no arguments.

Constructs a new environment and initializes it with the provided name and positional arguments.