Struct conch_runtime::env::atomic::Env[][src]

pub struct Env<A, IO, FD, L, V, EX, WD, N: Eq + Hash, ERR> { /* fields omitted */ }

A shell environment implementation which delegates work to other environment implementations.

Uses Arc internally. If Send and Sync is not required of the implementation, see Env as a cheaper alternative.

Methods

impl<A, IO, FD, L, V, EX, WD, N, ERR> AtomicEnv<A, IO, FD, L, V, EX, WD, N, ERR> where
    N: Hash + Eq
[src]

Creates an environment using the provided configuration of subcomponents.

See EnvConfig for the kinds of overrides possible. DefaultEnvConfig comes with provided implementations to get you up and running.

General recommendations:

  • The result of evaluating a shell word will often be copied and reused in many different places. It's strongly recommened that Rc or Arc wrappers (e.g. Rc<String>) be used to minimize having to reallocate and copy the same data.
  • Whatever type represents a shell function body needs to be cloned to get around borrow restrictions and potential recursive executions and (re-)definitions. Since this type is probably an AST (which may be arbitrarily large), Rc and Arc are your friends.