Struct conch_runtime::env::atomic::FnEnv[][src]

pub struct FnEnv<N: Hash + Eq, F> { /* fields omitted */ }

An environment module for setting and getting shell functions.

Uses Arc internally. If Send and Sync is not required of the implementation, see env::FnEnv as a cheaper alternative.

Methods

impl<N: Hash + Eq, F> AtomicFnEnv<N, F>
[src]

Constructs a new FnEnv with no defined functions.