Struct conch_runtime::env::atomic::VarEnv[][src]

pub struct VarEnv<N: Eq + Hash, V> { /* fields omitted */ }

An environment module for setting and getting shell variables.

Uses Arc internally. If Send and Sync is not required of the implementation, see env::VarEnv as a cheaper alternative.

Methods

impl<N: Eq + Hash, V> AtomicVarEnv<N, V>
[src]

Constructs a new environment with no environment variables.

Constructs a new environment and initializes it with the environment variables of the current process.

Constructs a new environment with a provided collection of (key, value) environment variable pairs. These variables (if any) will be inherited by all commands.