Struct conch_runtime::env::atomic::VirtualWorkingDirEnv [−][src]
pub struct VirtualWorkingDirEnv { /* fields omitted */ }An environment module for keeping track of the current working directory.
This is a "virtual" implementation because changing the working directory through this environment will not affect the working directory of the entire process.
Uses Arc internally. If Send and Sync is not required of the implementation,
see env::VirtualWorkingDirEnv as a cheaper alternative.
Methods
impl AtomicVirtualWorkingDirEnv[src]
impl AtomicVirtualWorkingDirEnvpub fn new<P: AsRef<Path>>(path: P) -> Result<Self>[src]
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self>Constructs a new environment with a provided working directory.
The specified path must be an absolute path or an error will result.
pub fn with_path_buf(path: PathBuf) -> Result<Self>[src]
pub fn with_path_buf(path: PathBuf) -> Result<Self>Constructs a new environment with a provided PathBuf as a working directory.
The specified path must be an absolute path or an error will result.
pub fn with_process_working_dir() -> Result<Self>[src]
pub fn with_process_working_dir() -> Result<Self>Constructs a new environment and initializes it with the current working directory of the current process.