Struct conch_runtime::env::ArgsEnv[][src]

pub struct ArgsEnv<T> { /* fields omitted */ }

An environment module for setting and getting shell and function arguments.

Uses Rc internally. For a possible Send and Sync implementation, see env::atomic::ArgsEnv.

Methods

impl<T> ArgsEnv<T>
[src]

Constructs a new environment and initializes it with the name of the current process as the shell name, and no arguments.

Constructs a new environment and initializes it with the provided name and no arguments.

Constructs a new environment and initializes it with the provided name and positional arguments.