Struct conch_runtime::env::ExecEnv [−][src]
pub struct ExecEnv { /* fields omitted */ }An ExecutableEnvironment implementation that uses a tokio event loop
to monitor when child processes have exited.
Note: Any futures/adapters returned by this implementation should be run on the same event loop that was associated with this environment, otherwise no progress may occur unless the associated event loop is turned externally.
Methods
impl ExecEnv[src]
impl ExecEnvpub fn new(remote: Remote) -> Self[src]
pub fn new(remote: Remote) -> SelfConstruct a new environment with a Remote to a tokio event loop.