Struct conch_runtime::env::FileDescEnv [−][src]
pub struct FileDescEnv<T> { /* fields omitted */ }An environment module for setting and getting shell file descriptors.
Uses Rc internally. For a possible Send and Sync implementation,
see env::atomic::FileDescEnv.
Methods
impl<T> FileDescEnv<T>[src]
impl<T> FileDescEnv<T>pub fn new() -> Self[src]
pub fn new() -> SelfConstructs a new environment with no open file descriptors.
pub fn with_process_stdio() -> Result<Self> where
T: From<FileDesc>, [src]
pub fn with_process_stdio() -> Result<Self> where
T: From<FileDesc>, Constructs a new environment and initializes it with duplicated stdio file descriptors or handles of the current process.
pub fn with_fds<I: IntoIterator<Item = (Fd, T, Permissions)>>(iter: I) -> Self[src]
pub fn with_fds<I: IntoIterator<Item = (Fd, T, Permissions)>>(iter: I) -> SelfConstructs a new environment with a provided collection of provided
file descriptors in the form (shell_fd, handle, permissions).