Struct conch_runtime::env::PlatformSpecificAsyncIoEnv [−][src]
pub struct PlatformSpecificAsyncIoEnv { /* fields omitted */ }A platform specific environment efficiently using a tokio event loop,
if the current platform supports efficient async IO, or a ThreadPoolAsyncIoEnv
otherwise.
Methods
impl PlatformSpecificAsyncIoEnv[src]
impl PlatformSpecificAsyncIoEnvpub fn new(remote: Remote, fallback_num_threads: Option<usize>) -> Self[src]
pub fn new(remote: Remote, fallback_num_threads: Option<usize>) -> SelfCreates a new platform specific environment using a tokio event loop,
if such an environment is supported on the current platform.
Otherwise, we will fall back to to a ThreadPoolAsyncIoEnv with the
specified number of threads. If None is specified, we'll use one
thread per CPU.