Struct conch_runtime::env::RedirectRestorer [−][src]
pub struct RedirectRestorer<E: ?Sized> where
E: FileDescEnvironment, { /* fields omitted */ }
Maintains a state of all file descriptors that have been modified so that they can be restored later.
Note: the caller should take care that a restorer instance is always called with the same environment for its entire lifetime. Using different environments with the same restorer instance will undoubtedly do the wrong thing eventually, and no guarantees can be made.
Methods
impl<E: ?Sized> RedirectRestorer<E> where
E: FileDescEnvironment, [src]
impl<E: ?Sized> RedirectRestorer<E> where
E: FileDescEnvironment, pub fn new() -> Self[src]
pub fn new() -> SelfCreate a new wrapper.
pub fn with_capacity(capacity: usize) -> Self[src]
pub fn with_capacity(capacity: usize) -> SelfCreate a new wrapper and reserve capacity for backing up the previous file descriptors of the environment.
pub fn reserve(&mut self, additional: usize)[src]
pub fn reserve(&mut self, additional: usize): use the RedirectEnvRestorer trait instead
Reserves capacity for at least additional more redirects to be backed up.
pub fn apply_action(
&mut self,
action: RedirectAction<E::FileHandle>,
env: &mut E
) -> IoResult<()> where
E: AsyncIoEnvironment,
E::FileHandle: Clone + From<FileDesc>, [src]
pub fn apply_action(
&mut self,
action: RedirectAction<E::FileHandle>,
env: &mut E
) -> IoResult<()> where
E: AsyncIoEnvironment,
E::FileHandle: Clone + From<FileDesc>, : use the RedirectEnvRestorer trait instead
Applies changes to a given environment after backing up as appropriate.
pub fn backup(&mut self, fd: Fd, env: &mut E) where
E::FileHandle: Clone, [src]
pub fn backup(&mut self, fd: Fd, env: &mut E) where
E::FileHandle: Clone, : use the RedirectEnvRestorer trait instead
Backs up the original handle of specified file descriptor.
The original value of the file descriptor is the one the environment held before it was passed into this wrapper. That is, if a file descriptor is backed up multiple times, only the value before the first call could be restored later.
pub fn restore(self, env: &mut E)[src]
pub fn restore(self, env: &mut E): use the RedirectEnvRestorer trait instead
Restore all file descriptors to their original state.