Struct conch_runtime::env::ThreadPoolAsyncIoEnv [−][src]
pub struct ThreadPoolAsyncIoEnv { /* fields omitted */ }An AsyncIoEnvironment implementation that uses a threadpool for doing
reads and writes on synchronous/blocking FileDesc handles.
This is a pretty costly implementation which may be required on systems that do not support asynchronous read/write operations (easily or at all). If running on a system that supports more efficient async operations, it is strongly encouraged to use an alternative implementation.
Note: Caller should ensure that any
FileDeschandles passed into this environment are not configured for asynchronous operations, otherwise operations will fail with aWouldBlockerror. This is done to avoid burning CPU cycles while spinning on read/write operations.
Methods
impl ThreadPoolAsyncIoEnv[src]
impl ThreadPoolAsyncIoEnvpub fn new(size: usize) -> Self[src]
pub fn new(size: usize) -> SelfCreates a new thread pool with size worker threads associated with it.
pub fn new_num_cpus() -> Self[src]
pub fn new_num_cpus() -> SelfCreates a new thread pool with a number of workers equal to the number of CPUs on the host.