Struct conch_runtime::env::VarEnv [−][src]
An environment module for setting and getting shell variables.
Uses Rc internally. For a possible Send and Sync implementation,
see env::atomic::VarEnv.
Methods
impl<N: Eq + Hash, V> VarEnv<N, V>[src]
impl<N: Eq + Hash, V> VarEnv<N, V>pub fn new() -> Self[src]
pub fn new() -> SelfConstructs a new environment with no environment variables.
pub fn with_process_env_vars() -> Self where
N: From<String>,
V: From<String>, [src]
pub fn with_process_env_vars() -> Self where
N: From<String>,
V: From<String>, Constructs a new environment and initializes it with the environment variables of the current process.
pub fn with_env_vars<I: IntoIterator<Item = (N, V)>>(iter: I) -> Self[src]
pub fn with_env_vars<I: IntoIterator<Item = (N, V)>>(iter: I) -> SelfConstructs a new environment with a provided collection of (key, value)
environment variable pairs. These variables (if any) will be inherited by
all commands.