Struct conch_runtime::env::VarRestorer [−][src]
pub struct VarRestorer<E: ?Sized> where
E: VariableEnvironment, { /* fields omitted */ }
Maintains a state of all variable definitions that have been modified so that they can be restored later.
Note: the caller should take care that a restorer instance is always called with the same environment for its entire lifetime. Using different environments with the same restorer instance will undoubtedly do the wrong thing eventually, and no guarantees can be made.
Methods
impl<E: ?Sized> VarRestorer<E> where
E: VariableEnvironment, [src]
impl<E: ?Sized> VarRestorer<E> where
E: VariableEnvironment, pub fn new() -> Self[src]
pub fn new() -> SelfCreate a new wrapper.
pub fn with_capacity(capacity: usize) -> Self[src]
pub fn with_capacity(capacity: usize) -> SelfCreate a new wrapper and reserve capacity for backing up the previous file descriptors of the environment.
pub fn restore(self, env: &mut E) where
E: ExportedVariableEnvironment + UnsetVariableEnvironment, [src]
pub fn restore(self, env: &mut E) where
E: ExportedVariableEnvironment + UnsetVariableEnvironment, : use the VarEnvRestorer trait instead
Restore all variable definitions to their original state.
impl<E: ?Sized> VarRestorer<E> where
E: ExportedVariableEnvironment,
E::VarName: Clone,
E::Var: Clone, [src]
impl<E: ?Sized> VarRestorer<E> where
E: ExportedVariableEnvironment,
E::VarName: Clone,
E::Var: Clone, pub fn set_exported_var(
&mut self,
name: E::VarName,
val: E::Var,
exported: bool,
env: &mut E
)[src]
pub fn set_exported_var(
&mut self,
name: E::VarName,
val: E::Var,
exported: bool,
env: &mut E
): use the VarEnvRestorer trait instead
Backup and set the value of some variable, maintaining its status as an environment variable if previously set as such.
pub fn unset_var(&mut self, name: E::VarName, env: &mut E) where
E: UnsetVariableEnvironment, [src]
pub fn unset_var(&mut self, name: E::VarName, env: &mut E) where
E: UnsetVariableEnvironment, : use the VarEnvRestorer trait instead
Backup and unset the value of some variable (including environment variables).
pub fn backup(&mut self, key: E::VarName, env: &E)[src]
pub fn backup(&mut self, key: E::VarName, env: &E): use the VarEnvRestorer trait instead
Backs up the original value of specified variable.
The original value of the variable is the one the environment held before it was passed into this wrapper. That is, if a variable is backed up multiple times, only the value before the first call could be restored later.