Struct conch_runtime::env::VirtualWorkingDirEnv [−][src]
pub struct VirtualWorkingDirEnv { /* fields omitted */ }An environment module for keeping track of the current working directory.
This is a "virtual" implementation because changing the working directory through this environment will not affect the working directory of the entire process.
Uses Rc internally. For a possible Send and Sync implementation,
see env::atomic::VirtualWorkingDirEnv.
Methods
impl VirtualWorkingDirEnv[src]
impl VirtualWorkingDirEnvpub fn new<P: AsRef<Path>>(path: P) -> Result<Self>[src]
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self>Constructs a new environment with a provided working directory.
The specified path must be an absolute path or an error will result.
pub fn with_path_buf(path: PathBuf) -> Result<Self>[src]
pub fn with_path_buf(path: PathBuf) -> Result<Self>Constructs a new environment with a provided PathBuf as a working directory.
The specified path must be an absolute path or an error will result.
pub fn with_process_working_dir() -> Result<Self>[src]
pub fn with_process_working_dir() -> Result<Self>Constructs a new environment and initializes it with the current working directory of the current process.