Enum conch_runtime::error::CommandError [−][src]
An error which may arise when spawning a command process.
Variants
NotFound(String)Unable to find a command/function/builtin to execute.
NotExecutable(String)Utility or script does not have executable permissions.
Io(IoError, Option<String>)Any I/O error returned by the OS during execution and the file that caused the error if applicable.