Enum conch_runtime::error::ExpansionError [−][src]
pub enum ExpansionError {
DivideByZero,
NegativeExponent,
BadAssig(String),
EmptyParameter(String, String),
}An error which may arise during parameter expansion.
Variants
DivideByZeroAttempted to divide by zero in an arithmetic subsitution.
NegativeExponentAttempted to raise to a negative power in an arithmetic subsitution.
BadAssig(String)Attempted to assign a special parameter, e.g. ${!:-value}.
EmptyParameter(String, String)Attempted to evaluate a null or unset parameter, i.e. ${var:?msg}.