Trait conch_runtime::error::IsFatalError [−][src]
Determines whether an error should be treated as "fatal".
Typically, "fatal" errors will abort any currently running commands (e.g. loops, compound commands, pipelines, etc.) all the way to a top level command, and consider it unsuccessful. On the other hand, non-fatal errors are usually swallowed by intermediate commands, and the execution is allowed to continue.
Ultimately it is up to the caller to decide how to handle fatal vs non-fatal errors.
Required Methods
Implementations on Foreign Types
impl IsFatalError for Void[src]
impl IsFatalError for VoidImplementors
impl IsFatalError for ExpansionErrorimpl IsFatalError for RedirectionErrorimpl IsFatalError for CommandErrorimpl IsFatalError for RuntimeErrorimpl<R, V> IsFatalError for EvalRedirectOrCmdWordError<R, V> where
R: IsFatalError,
V: IsFatalError,impl<R, V> IsFatalError for EvalRedirectOrVarAssigError<R, V> where
R: IsFatalError,
V: IsFatalError,