Enum conch_runtime::eval::RedirectOrVarAssig [−][src]
pub enum RedirectOrVarAssig<R, V, W> {
Redirect(R),
VarAssig(V, Option<W>),
}Represents a redirect or a defined environment variable at the start of a command.
Because the order in which redirects are defined may be significant for execution (i.e. due to side effects), we will process them in the order they were defined.
Variants
Redirect(R)A redirect defined before a command name.
VarAssig(V, Option<W>)A variable assignment, e.g. foo=[bar].