Enum conch_runtime::eval::TildeExpansion [−][src]
pub enum TildeExpansion {
None,
First,
All,
}An enum representing how tildes (~) are expanded.
Variants
NoneTildes retain a literal value, no expansion is done.
FirstTildes are expanded if they are at the beginning of a word.
AllAll tildes (either at start of word or after :) are expanded.