Struct conch_runtime::eval::Concat[][src]

#[must_use = "futures do nothing unless polled"]
pub struct Concat<W, I, E: ?Sized> where
    W: WordEval<E>,
    I: Iterator<Item = W>, 
{ /* fields omitted */ }

A future adapter which concatenates multiple words together.

All words will be concatenated together in the same field, however, intermediate At, Star, and Split fields will be handled as follows: the first newly generated field will be concatenated to the last existing field, and the remainder of the newly generated fields will form their own distinct fields.