Struct conch_runtime::io::FileDesc [−][src]
pub struct FileDesc(_);
A wrapper around an owned OS file primitive. The wrapper allows reading from or writing to the OS file primitive, and will close it once it goes out of scope.
Methods
impl FileDesc[src]
impl FileDescpub unsafe fn new(fd: RawFd) -> Self[src]
pub unsafe fn new(fd: RawFd) -> SelfTakes ownership of and wraps an OS file primitive.
pub fn duplicate(&self) -> Result<Self>[src]
pub fn duplicate(&self) -> Result<Self>Duplicates the underlying OS file primitive.