Struct conch_runtime::path::NormalizedPath [−][src]
pub struct NormalizedPath { /* fields omitted */ }A PathBuf wrapper which ensures paths do not have . or .. components.
Methods
impl NormalizedPath[src]
impl NormalizedPathpub fn new() -> Self[src]
pub fn new() -> SelfCreates a new, empty NormalizedPath.
pub fn new_normalized_logical(buf: PathBuf) -> Self[src]
pub fn new_normalized_logical(buf: PathBuf) -> SelfCreates a new NormalizedPath instance with the provided buffer.
If buf is non-empty, it will be logically normalized as needed.
See the documentation for join_normalized_logial for more
information on how the normalization is performed.
pub fn new_normalized_physical(buf: PathBuf) -> Result<Self, NormalizationError>[src]
pub fn new_normalized_physical(buf: PathBuf) -> Result<Self, NormalizationError>Creates a new NormalizedPath instance with the provided buffer.
If buf is non-empty, it will be physically normalized as needed.
See the documentation for join_normalized_physical for more
information on how the normalization is performed.
pub fn join_normalized_logial<P: AsRef<Path>>(&mut self, path: P)[src]
pub fn join_normalized_logial<P: AsRef<Path>>(&mut self, path: P)Joins a path to the buffer, normalizing away any . or .. components,
without following any symbolic links.
For example, joining ../some/path to /root/dir will yield
/root/some/path.
The normal behaviors of joining Paths will take effect (e.g. joining
with an absolute path will replace the previous contents).
pub fn join_normalized_physical<P: AsRef<Path>>(
&mut self,
path: P
) -> Result<(), NormalizationError>[src]
pub fn join_normalized_physical<P: AsRef<Path>>(
&mut self,
path: P
) -> Result<(), NormalizationError>Joins a path to the buffer, normalizing away any . or .. components
after following any symbolic links.
For example, joining ../some/path to /root/dir (where /root/dir
is a symlink to /root/another/place) will yield /root/another/some/path.
The normal behaviors of joining Paths will take effect (e.g. joining
with an absolute path will replace the previous contents).
Errors
If an error occurs while resolving symlinks, the current path buffer will be reset to its previous state (as if the call never happened) before the error is propagated to the caller.
pub fn into_inner(self) -> PathBuf[src]
pub fn into_inner(self) -> PathBufUnwraps the inner PathBuf.
Methods from Deref<Target = PathBuf>