Function conch_runtime::spawn::builtin::echo [−][src]
pub fn echo<I>(args: I) -> Echo<I::IntoIter> where
I: IntoIterator,
Creates a new echo builtin command with the provided arguments.
pub fn echo<I>(args: I) -> Echo<I::IntoIter> where
I: IntoIterator,
Creates a new echo builtin command with the provided arguments.