Function conch_runtime::spawn::builtin::shift [−][src]
pub fn shift<I>(args: I) -> Shift<I::IntoIter> where
I: IntoIterator,
Creates a new shift builtin command with the provided arguments.
pub fn shift<I>(args: I) -> Shift<I::IntoIter> where
I: IntoIterator,
Creates a new shift builtin command with the provided arguments.