Struct conch_runtime::spawn::GuardBodyPair [−][src]
pub struct GuardBodyPair<T> {
pub guard: T,
pub body: T,
}A grouping of guard and body commands.
Fields
guard: T
The guard commands, which if successful, should lead to the execution of the body commands.
body: T
The body commands to execute if the guard is successful.