Struct conch_runtime::spawn::SubstitutionEnvFuture [−][src]
#[must_use = "futures do nothing unless polled"]pub struct SubstitutionEnvFuture<I> { /* fields omitted */ }
A future that represents the spawning of a command substitution.
The standard output of the commands will be captured and trailing newlines trimmed.