Enum conch_runtime::spawn::AndOr [−][src]
pub enum AndOr<T> {
And(T),
Or(T),
}A command which conditionally runs based on the exit status of the previous command.
Variants
And(T)A compound command which should run only if the previously run command succeeded.
Or(T)A compound command which should run only if the previously run command failed.